@@ -1,5 +1,5 @@
 /* grep.h - interface to grep driver for searching subroutines.
-   Copyright (C) 1992, 1998 Free Software Foundation, Inc.
+   Copyright (C) 1992, 1998, 2001 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -20,20 +20,16 @@
 # define __attribute__(x)
 #endif
 
-extern void fatal PARAMS ((const char *, int)) __attribute__((noreturn));
-extern char *xmalloc PARAMS ((size_t size));
-extern char *xrealloc PARAMS ((char *ptr, size_t size));
-
 /* Grep.c expects the matchers vector to be terminated
-   by an entry with a NULL name, and to contain at least
+   by an entry with a NULL compile, and to contain at least
    an entry named "default". */
 
 extern struct matcher
 {
-  char *name;
-  void (*compile) PARAMS ((char *, size_t));
-  char *(*execute) PARAMS ((char *, size_t, char **));
-} matchers[];
+  char name[8];
+  void (*compile) PARAMS ((char const *, size_t));
+  size_t (*execute) PARAMS ((char const *, size_t, size_t *, int));
+} const matchers[];
 
 /* Exported from fgrepmat.c, egrepmat.c, grepmat.c.  */
 extern char const *matcher;
